<?php
	/***************************************************************
	*  Copyright notice
	*
	*  (c) 2004/2005 Martin Tschosnig (martin.tschosnig@udo.edu)
	*  All rights reserved
	*
	*  This script is part of the TYPO3 project. The TYPO3 project is
	*  free software; you can redistribute it and/or modify
	*  it under the terms of the GNU General Public License as published by
	*  the Free Software Foundation; either version 2 of the License, or
	*  (at your option) any later version.
	*
	*  The GNU General Public License can be found at
	*  http://www.gnu.org/copyleft/gpl.html.
	*  A copy is found in the textfile GPL.txt and important notices to the license
	*  from the author is found in LICENSE.txt distributed with these scripts.
	*
	*
	*  This script is distributed in the hope that it will be useful,
	*  but WITHOUT ANY WARRANTY; without even the implied warranty of
	*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	*  GNU General Public License for more details.
	*
	*  This copyright notice MUST APPEAR in all copies of the script!
	***************************************************************/
	/**
	* Include file containing functions to build an sliding image
	*
	* @author Martin Tschosnig (martin.tschosnig@udo.edu)
	*/
	/**
	* [CLASS/FUNCTION INDEX of SCRIPT]
	*
	*
	*
	*   52: class tx_mtslide_slideLib
	*   66:     function getScript($repeat_h, $repeat_v, $id)
	*  104:     function makeSlideImage($wHeight, $wWidth, $grid, $id, $float)
	*
	* TOTAL FUNCTIONS: 2
	* (This index is automatically created/updated by the extension "extdeveval")
	*
	*/
	/**
	* Class containig functions for creating sliding images
	*
	* @author Martin Tschosnig (martin.tschosnig@udo.edu)
	*/
	class tx_mtslide_slideLib {
		 
		var $nlChar;
		 
		 
		/**
		* Create the JavaScript for the content depending on the sliding directions.
		* Image can be scrolled horizontally or vertically or both.
		*
		* @param integer  If 1, image is repeated horizontally
		* @param integer  If 1, image is repeated vertically
		* @param string  image-id, used to recognize the img in JS
		* @return string  Returns the correct JavaScript code
		*/
		function getScript($repeat_h, $repeat_v, $id) {
			 
			$this->nlChar = chr(13).chr(10);
			if ($repeat_h == 1) {
				$content = 'slidePosH'.$id.' = (slidePosH'.$id.' + slideSpeedH'.$id.') % imageWidth'.$id.';'.$this->nlChar;
				if ($repeat_v == 1) {
					$content .= 'slidePosV'.$id.' = (slidePosV'.$id.' + slideSpeedV'.$id.') % imageHeight'.$id.';';
				} else {
					$content .= 'slidePosV'.$id.' += slideSpeedV'.$id.';'.$this->nlChar;
					$content .= 'slidePosV'.$id.' = ((slidePosV'.$id.' > 0) ? 0 : slidePosV'.$id.');'.$this->nlChar;
					$content .= 'slidePosV'.$id.' = ((slidePosV'.$id.' < borderV'.$id.') ? borderV'.$id.' : slidePosV'.$id.');';
				}
			} else {
				$content = 'slidePosH'.$id.' += slideSpeedH'.$id.';'.$this->nlChar;
				$content .= 'slidePosH'.$id.' = ((slidePosH'.$id.' > 0) ? 0 : slidePosH'.$id.');'.$this->nlChar;
				$content .= 'slidePosH'.$id.' = ((slidePosH'.$id.' < borderH'.$id.') ? borderH'.$id.' : slidePosH'.$id.');'.$this->nlChar;
				if ($repeat_v == 1) {
					$content .= 'slidePosV'.$id.' = (slidePosV'.$id.' + slideSpeedV'.$id.') % imageHeight'.$id.';';
				} else {
					$content .= 'slidePosV'.$id.' += slideSpeedV'.$id.';'.$this->nlChar;
					$content .= 'slidePosV'.$id.' = ((slidePosV'.$id.' > 0) ? 0 : slidePosV'.$id.');'.$this->nlChar;
					$content .= 'slidePosV'.$id.' = ((slidePosV'.$id.' < borderV'.$id.') ? borderV'.$id.' : slidePosV'.$id.');';
				}
			}
			return $content;
		}
		 
		/**
		* Calculate the count of rows/cols of the sliding grid, calculate the size of a cell,
		* build grid over the picture and add onMouseOver-events.
		*
		* @param integer  Height of the sliding window
		* @param integer  Width of the sliding window		
		* @param integer  sliding grid resolution factor
		* @param string		ID of the sliding image. used for multiple images on one site.
		* @param boolean  Should the image float?
		* @return string  Returns the HTML code of an sliding image, without JavaScript, XHTML
		*/
		function makeSlideImage($wHeight, $wWidth, $grid, $id, $float) {
			 
			$this->nlChar = chr(13).chr(10);
			// get number of rows/cols and their width/height
			// min rows = 3;
			$i = 3;
			$finished = false;
			while ($finished == false) {
				if (intval($wHeight / $i) < (8 * $grid)) {
					$verticalCellsCount = $i;
					$cellsHeight = intval($wHeight / $i);
					$v_buffer = 0;
					while ((($i * $cellsHeight)+$v_buffer) < $wHeight) {
						$v_buffer++;
					}
					while ($v_buffer > $i) {
						$cellsHeight++;
						$v_buffer -= $i;
					}
					$finished = true;
				}
				$i = $i+2;
			}
			// the middle cell is bigger than the others
			$middleCellWidth = intval($wWidth / 10) > (12 * $grid) ? (12 * $grid) :
			 intval($wWidth / 10);
			// min cols = 8
			$i = 6;
			$finished = false;
			while ($finished == false) {
				if (intval(($wWidth-$middleCellWidth) / $i) < (10 * $grid)) {
					$horizontalCellsCount = $i;
					$cellsWidth = intval(($wWidth-$middleCellWidth) / $i);
					if ((($i * $cellsWidth)+$middleCellWidth) < ($wWidth)) {
						while ((($i * $cellsWidth)+$middleCellWidth) < ($wWidth)) {
							$middleCellWidth++;
						}
					} elseif ((($i * $cellsWidth)+$middleCellWidth) > ($wWidth)) {
						while ((($i * $cellsWidth)+$middleCellWidth) > ($wWidth)) {
							$middleCellWidth--;
						}
					}
					$finished = true;
				}
				$i = $i+2;
			}
			$content = '<table class="tx-mtslide-maintable">'.$this->nlChar.'<tr><td>'.$this->nlChar;
			$content .= '<div id="tx-mtslide-slideimage'.$id.'">';
			 
			$content .= '<table class="tx-mtslide-slideTable"><tr>'.$this->nlChar;
			 
			$tmp = '';
			for ($i = 0; $i < ($horizontalCellsCount/2); $i++) {
				$tmp .= '<td>'.$this->nlChar;
				for ($j = 1; $j <= (($verticalCellsCount+1)/2); $j++) {
					$tmp .= '<img alt="" onmouseover="setSlideSpeed'.$id.'('.($horizontalCellsCount/2-$i).','.((($verticalCellsCount+1)/2)-$j).');" onmouseout="setSlideSpeed'.$id.'(0,0);" src="clear.gif" width="'.$cellsWidth.'" height="'.$cellsHeight.'" /><br />'.$this->nlChar;
				}
				for ($j = (($verticalCellsCount+1)/2)-1; $j >= 1; $j--) {
					$tmp .= '<img alt="" onmouseover="setSlideSpeed'.$id.'('.($horizontalCellsCount/2-$i).',-'.((($verticalCellsCount+1)/2)-$j).');" onmouseout="setSlideSpeed'.$id.'(0,0);" src="clear.gif" width="'.$cellsWidth.'" height="'.$cellsHeight.'" /><br />'.$this->nlChar;
				}
				$tmp .= '</td>'.$this->nlChar;
			}
			// middle cell
			$tmp .= '<td>'.$this->nlChar;
			for ($j = 1; $j <= (($verticalCellsCount+1)/2); $j++) {
				$tmp .= '<img alt="" onmouseover="setSlideSpeed'.$id.'(0,'.((($verticalCellsCount+1)/2)-$j).');" onmouseout="setSlideSpeed'.$id.'(0,0);" src="clear.gif" width="'.$middleCellWidth.'" height="'.$cellsHeight.'" /><br />'.$this->nlChar;
			}
			for ($j = (($verticalCellsCount+1)/2)-1; $j >= 1; $j--) {
				$tmp .= '<img alt="" onmouseover="setSlideSpeed'.$id.'(0,-'.((($verticalCellsCount+1)/2)-$j).');" onmouseout="setSlideSpeed'.$id.'(0,0);" src="clear.gif" width="'.$middleCellWidth.'" height="'.$cellsHeight.'" /><br />'.$this->nlChar;
			}
			$tmp .= '</td>';
			 
			for ($i = ($horizontalCellsCount/2)-1; $i >= 0; $i--) {
				$tmp .= '<td>'.$this->nlChar;
				for ($j = 1; $j <= (($verticalCellsCount+1)/2); $j++) {
					$tmp .= '<img alt="" onmouseover="setSlideSpeed'.$id.'(-'.($horizontalCellsCount/2-$i).','.((($verticalCellsCount+1)/2)-$j).');" onmouseout="setSlideSpeed'.$id.'(0,0);" src="clear.gif" width="'.$cellsWidth.'" height="'.$cellsHeight.'" /><br />'.$this->nlChar;
				}
				for ($j = (($verticalCellsCount+1)/2)-1; $j >= 1; $j--) {
					$tmp .= '<img alt="" onmouseover="setSlideSpeed'.$id.'(-'.($horizontalCellsCount/2-$i).',-'.((($verticalCellsCount+1)/2)-$j).');" onmouseout="setSlideSpeed'.$id.'(0,0);" src="clear.gif" width="'.$cellsWidth.'" height="'.$cellsHeight.'" /><br />'.$this->nlChar;
				}
				$tmp .= '</td>';
			}
			$content .= $tmp;
			$content .= '</tr></table>'.$this->nlChar.'</div></td></tr>'.$this->nlChar.'</table>';
			if ($float == 0)
				$content .= '<div style="clear:both; visibiliy:hiddden;"></div>';
			 
			return $content;
		}
	}
	 
	if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/mt_slide/tx_mtslide_slidelib.php']) {
		include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/mt_slide/tx_mtslide_slidelib.php']);
	}
?>
